==> release.12.2.28.1.tgz: cgi-cpn/utils/prontus_dropbox_full_backup.pl <==
#!/usr/bin/perl
# ---------------------------------------------------------------
# Prontus CMS
# http://www.prontus.cl
# by Altavoz.net
#
# licensed under LGPL license.
# http://www.prontus.cl/license.html
# ---------------------------------------------------------------
#
# Respalda todo el directorio site en dropbox.
#
# Uso:
# Mediante la linea de comandos:
#   $ /usr/bin/perl prontus_dropbox_full_backup.pl <prontus id>
#
#   donde:
#       <prontus id> = Nombre del directorio de la instancia de Prontus a respaldar.
#
# Para respaldar el sitio web completo u otros directorios se puede alterar la
# llamada a la funcion &recurseDirs al final del bloque main.
# Recordar que para respaldar el sitio web completo el diretorio raiz se indica
# en Dropbox como "" en lugar de "/".
#
use strict;
use utf8;

BEGIN {
    use FindBin qw($Bin);
    unshift(@INC,$Bin); # Para dejar disponibles las librerias
    my $pathLibsProntus = $Bin;
    $pathLibsProntus =~ s/\/[^\/]+\/?$//;
    unshift(@INC,$pathLibsProntus); # Para dejar disponibles las librerias de prontus
}

use sigtrap 'handler' => \&signal_catch, 'INT';
use sigtrap 'handler' => \&signal_catch, 'TERM';
use sigtrap 'handler' => \&signal_catch, 'KILL';


##libs##
use lib_stdlog;
lib_stdlog::set_stdlog($0, 51200);
use prontus_varglb;
prontus_varglb::init();

use File::Copy;
use HTTP::Request;
use JSON;
use LWP::UserAgent;
use glib_fildir_03;
use lib_dropbox;
use lib_utils;
##/libs##

main: {
    lib_utils::setUtf8();

    my $prontus_id = $ARGV[0];

    if ($prontus_id eq '') {
        print "Debe indicar nombre de la instacia de Prontus.\n";
        print "perl prontus_dropbox_full_backup.pl <prontus id>.\n";
        exit;
    }

    # Carga variables de configuracion de prontus.
    my $msg_load = lib_utils::load_config_by_id($prontus_id);
    if ($msg_load ne '') {
        print "$msg_load\n";
        exit;
    }

    if ($prontus_varglb::CONFIG{$prontus_id}{'DROPBOX'} eq 'NO') {
        print "El respaldo en Dropbox no esta habilitado.\n";
        exit;
    }

    # Inicializa modulo dropbox.
    lib_dropbox::init($prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DROPBOX_REFRESH_TOKEN'});

    # Prueba acceso a dropbox.
    my $info = lib_dropbox::getInfo();
    print "Info = [$info]\n";
    if (! $info) {
        print "No hay acceso a dropbox. Revise el access token.\n";
        exit;
    }
    print "Elementos en la raiz del respaldo en Dropbox:\n";
    my @entries = &lib_dropbox::getDir('');
    foreach my $entry (@entries) {
        print "$entry\n";
    }
    print "\n";

    # Copia todo el site a Dropbox.
    print "***** Inicio del respaldo completo del directorio site *****\n";
    &recurseDirs("$prontus_varglb::DIR_SERVER/$prontus_id/site","/$prontus_id/site");
    print "***** Fin del respaldo completo del directorio site *****\n";
}

# Recorre los directorios recursivamente, subiendo a Dropbox los archivos que no
# existen o que tienen un peso distinto.
# @param string source el path completo al directorio a respaldar
# @param string destination el path relativo de destino en Dropbox.
# Debe ser el nombre del directorio de Prontus, para mantener la misma estructura.
sub recurseDirs {
    my ($source,$destination) = @_;
    print "Inicio: $source -> $destination\n";
    opendir(DIR, $source) || die "Can't opendir " . $source . $!;
    my @entries = readdir(DIR);
    closedir DIR;

    # Lee las entradas de dropbox en el destino.
    my @dropboxEntries = &lib_dropbox::getDir($destination);

    # Obtiene los tamanos de archivo. Si es un directorio asigna el tamano -1.
    my %dropboxFileSizes = ();
    print " Listado de $destination en dropbox:\n";
    foreach my $dropBoxEntry (@dropboxEntries) {
        my ($path,$esdir,$size) = split(/\t/,$dropBoxEntry);

        # Elimina los directorios superiores del path.
        if ($path =~ /\/([^\/]+)$/) {
            $path = $1;
        }else{
            $path = '/';
        }

        # Asigna el tamano.
        if ($esdir) {
            $dropboxFileSizes{$path} = -1;
        }else{
            $dropboxFileSizes{$path} = $size;
        }
        print " $path $size\n";
    }

    # Recorre los archivos y subdirectorios.
    foreach my $entry (sort @entries) {
        print "Local: $source/$entry\n";

        # Si es un directorio, entonces aplica de nuevo la rutina en forma recursiva.
        # No copia los directorios que empiezan con un punto.
        if ((-d "$source/$entry") && ($entry !~ /^\./)) {
            &recurseDirs("$source/$entry","$destination/$entry");
        }
        if (-f "$source/$entry") {
            # Si no existe en dropbox o si los tamanos son distintos, lo sube.
            if ( (! $dropboxFileSizes{$entry}) || ( $dropboxFileSizes{$entry} != -s "$source/$entry") ) {
                print " sube: $source/$entry $destination/$entry\n";
                print &lib_dropbox::putFile("$source/$entry","$destination/$entry");
                print "\n";
            }
        }
    }
} # recurseDirs

# ----------------------------------------------------------------------------- #
# funcion para capturar las senales INT y TERM.
sub signal_catch {
    print "Terminado por signal @_\n";
    exit(0);
} # signal_catch

==> release.12.3.1.2.tgz: cgi-cpn/utils/prontus_dropbox_full_backup.pl <==
#!/usr/bin/perl
# ---------------------------------------------------------------
# Prontus CMS
# http://www.prontus.cl
# by Altavoz.net
#
# licensed under LGPL license.
# http://www.prontus.cl/license.html
# ---------------------------------------------------------------
#
# Respalda todo el directorio site en dropbox.
#
# Uso:
# Mediante la linea de comandos:
#   $ /usr/bin/perl prontus_dropbox_full_backup.pl <prontus id>
#
#   donde:
#       <prontus id> = Nombre del directorio de la instancia de Prontus a respaldar.
#
# Para respaldar el sitio web completo u otros directorios se puede alterar la
# llamada a la funcion &recurseDirs al final del bloque main.
# Recordar que para respaldar el sitio web completo el diretorio raiz se indica
# en Dropbox como "" en lugar de "/".
#
use strict;
use utf8;

BEGIN {
    use FindBin qw($Bin);
    unshift(@INC,$Bin); # Para dejar disponibles las librerias
    my $pathLibsProntus = $Bin;
    $pathLibsProntus =~ s/\/[^\/]+\/?$//;
    unshift(@INC,$pathLibsProntus); # Para dejar disponibles las librerias de prontus
}

use sigtrap 'handler' => \&signal_catch, 'INT';
use sigtrap 'handler' => \&signal_catch, 'TERM';
use sigtrap 'handler' => \&signal_catch, 'KILL';

##libs##
use lib_stdlog;
lib_stdlog::set_stdlog($0, 51200);
use prontus_varglb;
prontus_varglb::init();

use File::Copy;
use HTTP::Request;
use JSON;
use LWP::UserAgent;
use glib_fildir_03;
use glib_hrfec_03;
use lib_dropbox;
use lib_lang;
use lib_utils;
##/libs##

main: {
    lib_utils::setUp();
    my $prontus_id = $ARGV[0];

    if ($prontus_id eq '') {
        print lib_lang::get_message('global_use_instructions');
        print "perl prontus_dropbox_full_backup.pl <prontus id>.\n";
        exit;
    }

    # Carga variables de configuracion de prontus.
    my $msg_load = lib_utils::load_config_by_id($prontus_id);
    if ($msg_load ne '') {
        print "$msg_load\n";
        exit;
    }

    if ($prontus_varglb::CONFIG{$prontus_id}{'DROPBOX'} eq 'NO') {
        print lib_lang::get_message('utils_dropbox_disabled');
        exit;
    }

    # Inicializa modulo dropbox.
    lib_dropbox::init($prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DROPBOX_REFRESH_TOKEN'});

    # Prueba acceso a dropbox.
    my $info = lib_dropbox::getInfo();
    print "Info = [$info]\n";
    if (! $info) {
        print lib_lang::get_message('utils_dropbox_no_access');
        exit;
    }

    print lib_lang::get_message('utils_dropbox_root_list');
    my @entries = &lib_dropbox::getDir('');
    foreach my $entry (@entries) {
        print "$entry\n";
    }
    print "\n";

    # Copia todo el site a Dropbox.
    print "[".glib_hrfec_03::fecha_human()." ". glib_hrfec_03::hora_human()."] ";
    print lib_lang::get_message('global_start_process') . "\n";
    &recurseDirs("$prontus_varglb::DIR_SERVER/$prontus_id/site","/$prontus_id/site");
    print "[".glib_hrfec_03::fecha_human()." ". glib_hrfec_03::hora_human()."] ";
    print lib_lang::get_message('global_end_process') . "\n";
}

# Recorre los directorios recursivamente, subiendo a Dropbox los archivos que no
# existen o que tienen un peso distinto.
# @param string source el path completo al directorio a respaldar
# @param string destination el path relativo de destino en Dropbox.
# Debe ser el nombre del directorio de Prontus, para mantener la misma estructura.
sub recurseDirs {
    my ($source,$destination) = @_;
    print lib_lang::get_message('global_start'), ": $source -> $destination\n";
    opendir(DIR, $source) || die "Can't opendir " . $source . $!;
    my @entries = readdir(DIR);
    closedir DIR;

    # Lee las entradas de dropbox en el destino.
    my @dropboxEntries = &lib_dropbox::getDir($destination);

    # Obtiene los tamanos de archivo. Si es un directorio asigna el tamano -1.
    my %dropboxFileSizes = ();
    print lib_lang::get_interpolated_message('utils_dropbox_dir_list', $destination);
    foreach my $dropBoxEntry (@dropboxEntries) {
        my ($path,$esdir,$size) = split(/\t/,$dropBoxEntry);

        # Elimina los directorios superiores del path.
        if ($path =~ /\/([^\/]+)$/) {
            $path = $1;
        }else{
            $path = '/';
        }

        # Asigna el tamano.
        if ($esdir) {
            $dropboxFileSizes{$path} = -1;
        }else{
            $dropboxFileSizes{$path} = $size;
        }
        print " $path $size\n";
    }

    # Recorre los archivos y subdirectorios.
    foreach my $entry (sort @entries) {
        print lib_lang::get_message('dropbox_local_label') , ": $source/$entry\n";

        # Si es un directorio, entonces aplica de nuevo la rutina en forma recursiva.
        # No copia los directorios que empiezan con un punto.
        if ((-d "$source/$entry") && ($entry !~ /^\./)) {
            &recurseDirs("$source/$entry","$destination/$entry");
        }
        if (-f "$source/$entry") {
            # Si no existe en dropbox o si los tamanos son distintos, lo sube.
            if ( (! $dropboxFileSizes{$entry}) || ( $dropboxFileSizes{$entry} != -s "$source/$entry") ) {
                print lib_lang::get_message('dropbox_upload_label'), ": $source/$entry $destination/$entry\n";
                print &lib_dropbox::putFile("$source/$entry","$destination/$entry");
                print "\n";
            }
        }
    }
} # recurseDirs

# ----------------------------------------------------------------------------- #
# funcion para capturar las senales INT y TERM.
sub signal_catch {
    print STDERR lib_lang::get_interpolated_message('global_ended_by_signal', "@_");
    exit(0);
} # signal_catch
